@@ -44,6 +44,7 @@ class User(api.BaseAuth):
             self.__cookie_info = None
             self.__presence = None
             self.__friends = None
+            self.__status = None
             self.__groups = None
             self.__rap = None
 
@@ -71,6 +72,34 @@ class User(api.BaseAuth):
             raise UserWarning('Authentication required for this endpoint, session must be set')
         return self.__cookie_info
 
+    @property
+    def status(self) -> str:
+        """
+        Contains information about the current user's status.
+
+        :return: str
+        """
+        if not self.__status:
+            data = requests.get(f'{api.user}/users/{self.id}/status').json()
+            self.__status = data['status']
+        return self.__status
+
+    @status.setter
+    def status(self, status: str):
+        """
+        Sets the current user's status.
+
+        :param status: New status to set.
+        """
+        if self.session:
+            data = self.session.patch(f'{api.user}/users/{self.id}/status', data={'status': status}).json()
+            if data.get('errors', ''):
+                utils.handle_code(data['errors'][0]['code'])
+            else:
+                self.__status = data['status']
+        else:
+            raise UserWarning('Authentication required for this endpoint, session must be set')
+
     @property
     def friends(self) -> List['User']:
         """
@@ -150,6 +179,47 @@ class User(api.BaseAuth):
                 raise UserWarning('Authentication required for this endpoint, session must be set')
         return self.__presence
 
+    def change_description(self, description: str, pin: str = None):
+        """
+        Sets a new description for the current user.
+
+        :param description: New description to set.
+        :param pin: Optional: Account PIN to unlock settings if applicable.
+        """
+        if self.session:
+            if pin:
+                self.session.post(api.auth, data={'pin': pin})
+            data = self.session.post(f'{api.account}/description', data={'description': description}).json()
+            if data.get('errors', ''):
+                utils.handle_code(data['errors'][0]['code'])
+            else:
+                self.description = self.session.get(f'{api.account}/description').json()['description']
+        else:
+            raise UserWarning('Authentication required for this endpoint, session must be set')
+
+    def message(self, subject: str, body: str, recipient: Union['User', int] = None):
+        """
+        Sends a message to the current user or the given recipient.
+
+        :param subject: The subject to use for the message.
+        :param body: The message itself to send.
+        :param recipient: Optional: Recipient to send the message to in the form of a User object or the userid.
+        """
+        if self.session:
+            if recipient:
+                _id = recipient if isinstance(recipient, int) else recipient.id
+            else:
+                _id = self.id
+            data = self.session.post(f'{api.messages}/messages/send', data={
+                'userId': self.by_cookie(self.session.cookies['.ROBLOSECURITY']).id, 'subject': subject, 'body': body,
+                'recipientId': _id}).json()
+            if data.get('errors', ''):
+                utils.handle_code(data['errors'][0]['code'])
+            elif not data.get('success', ''):
+                raise UserWarning('Error occurred sending message')
+        else:
+            raise UserWarning('Authentication required for this endpoint, session must be set')
+
     @classmethod
     def by_username(cls, username: str) -> 'User':
         """
@@ -166,11 +236,12 @@ class User(api.BaseAuth):
         return cls(data['data'][0]['id'])
 
     @classmethod
-    def by_cookie(cls, cookie: str) -> 'User':
+    def by_cookie(cls, cookie: str, proxies: List[str] = None) -> 'User':
         """
         Class method that returns a User object based on the given cookie rather than username or id.
 
         :param cookie: The cookie of the user to create an object of.
+        :param proxies: Optional: List of proxies to use with a single cookie or several cookies.
         :return: User
         """
         sess = requests.session()
@@ -182,7 +253,10 @@ class User(api.BaseAuth):
         except:
             raise UserWarning('Invalid cookie')
         else:
-            return cls(data['UserID'], cookie)
+            if proxies:
+                return cls(data['UserID'], cookie, proxies=proxies)
+            else:
+                return cls(data['UserID'], cookie)
 
 
 class Shout:
